BinderScopes

Struct BinderScopes 

pub struct BinderScopes<'a> { /* private fields */ }

Implementations

Source

impl<'a> BinderScopes<'a>

pub fn new(unit: CompileUnit<'a>, globals: &'a Scope<'a>) -> Self

pub fn top(&self) -> &'a Scope<'a>

pub fn unit(&self) -> CompileUnit<'a>

pub fn interner(&self) -> &InternPool

pub fn scopes(&self) -> &ScopeStack<'a>

pub fn scopes_mut(&mut self) -> &mut ScopeStack<'a>

pub fn scope_depth(&self) -> usize

Gets the current depth of the scope stack.

  • 0 means no scope has been pushed yet
  • 1 means global scope is active
  • 2+ means nested scopes are active
pub fn push_scope(&mut self, id: ScopeId)

Pushes a scope onto the stack by looking it up from the compilation unit.

pub fn push_scope_recursive(&mut self, id: ScopeId)

Pushes a scope recursively with all its parent scopes.

pub fn push_scope_node(&mut self, sn: &'a HirScope<'a>)

Pushes the scope represented by a HirScope node.

pub fn pop_scope(&mut self)

Pops the current scope from the stack.

pub fn pop_until(&mut self, depth: usize)

Pops scopes until reaching the specified depth.

pub fn globals(&self) -> &'a Scope<'a>

Gets the global scope (always at index 0).

pub fn lookup_globals( &self, name: &str, kind_filters: SymKindSet, ) -> Option<Vec<&'a Symbol>>

pub fn lookup_global( &self, name: &str, kind_filters: SymKindSet, ) -> Option<&'a Symbol>

pub fn lookup_symbols( &self, name: &str, kind_filters: SymKindSet, ) -> Option<Vec<&'a Symbol>>

Lookup symbols by name with options

pub fn lookup_symbol( &self, name: &str, kind_filters: SymKindSet, ) -> Option<&'a Symbol>

pub fn lookup_member_symbols( &self, obj_type_symbol: &'a Symbol, member_name: &str, kind_filters: SymKindSet, ) -> Option<&'a Symbol>

Look up a member symbol in a type’s scope.

pub fn lookup_member_symbol( &self, obj_type_symbol: &'a Symbol, member_name: &str, kind_filter: Option<SymKind>, ) -> Option<&'a Symbol>

Look up a member symbol in a type’s scope.

pub fn lookup_qualified( &self, qualified_name: &[&str], kind_filters: SymKindSet, ) -> Option<Vec<&'a Symbol>>

Look up a qualified path (e.g., foo::Bar::baz) with optional kind filters.

pub fn lookup_qualified_symbol( &self, qualified_name: &[&str], kind_filters: SymKindSet, ) -> Option<&'a Symbol>

Look up a qualified path and apply same-crate preference for multi-crate scenarios.